package org.dromara.game.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.game.domain.bo.PlatChannelBo;
import org.dromara.game.domain.vo.PlatChannelVo;

import java.util.Collection;
import java.util.List;

/**
 * 渠道Service接口
 *
 * @author Hixon
 * @date 2024-08-07
 */
public interface IPlatChannelService {

    /**
     * 查询渠道
     *
     * @param id 主键
     * @return 渠道
     */
    PlatChannelVo queryById(Long id);

    /**
     * 分页查询渠道列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 渠道分页列表
     */
    TableDataInfo<PlatChannelVo> queryPageList(PlatChannelBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的渠道列表
     *
     * @param bo 查询条件
     * @return 渠道列表
     */
    List<PlatChannelVo> queryList(PlatChannelBo bo);

    /**
     * 新增渠道
     *
     * @param bo 渠道
     * @return 是否新增成功
     */
    Boolean insertByBo(PlatChannelBo bo);

    /**
     * 修改渠道
     *
     * @param bo 渠道
     * @return 是否修改成功
     */
    Boolean updateByBo(PlatChannelBo bo);

    /**
     * 校验并批量删除渠道信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
