package org.dromara.game.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.game.domain.bo.PlatProductProxyBo;
import org.dromara.game.domain.vo.PlatProductProxyVo;

import java.util.Collection;
import java.util.List;

/**
 * 产品代理商Service接口
 *
 * @author Hixon
 * @date 2024-08-07
 */
public interface IPlatProductProxyService {

    /**
     * 查询产品代理商
     *
     * @param id 主键
     * @return 产品代理商
     */
    PlatProductProxyVo queryById(Long id);

    /**
     * 分页查询产品代理商列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 产品代理商分页列表
     */
    TableDataInfo<PlatProductProxyVo> queryPageList(PlatProductProxyBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的产品代理商列表
     *
     * @param bo 查询条件
     * @return 产品代理商列表
     */
    List<PlatProductProxyVo> queryList(PlatProductProxyBo bo);

    /**
     * 新增产品代理商
     *
     * @param bo 产品代理商
     * @return 是否新增成功
     */
    Boolean insertByBo(PlatProductProxyBo bo);

    /**
     * 修改产品代理商
     *
     * @param bo 产品代理商
     * @return 是否修改成功
     */
    Boolean updateByBo(PlatProductProxyBo bo);

    /**
     * 校验并批量删除产品代理商信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
